import logging
import os

import requests

import util.system

session = requests.Session()
logger = logging.getLogger(__name__)

def sync_center():
    """
    通过接口获取任务
    :return: 任务列表
    """
    try:
        response = session.post(os.getenv('API_ENDPOINT'), json={
            'accessKey': os.getenv('ACCESS_KEY'),
            'clientStatus': util.system.get_sys_info()
        }, timeout=10)
    except requests.RequestException as e:
        logger.error("请求失败！", e)
        return []
    data = response.json()
    logger.debug("获取任务结果：【%s】", data)
    if data.get('code', 0) == 200:
        tasks = data.get('data', {}).get('tasks', [])
    else:
        tasks = []
        logger.warning("获取任务失败")
    return tasks


def get_template_info(template_id):
    """
    通过接口获取模板信息
    :rtype: Template
    :param template_id: 模板id
    :type template_id: str
    :return: 模板信息
    """
    template = {
        'id': template_id,
        'name': '模板名称',
        'description': '模板描述',
        'video_size': '1920x1080',
        'frame_rate': 30,
        'overall_duration': 30,
        'video_parts': [
            {
                'source': './template/test_template/1.mp4',
                'mute': True,
            },
            {
                'source': 'PLACEHOLDER_CAM_ID',
                'mute': True,
                'overlays': [
                    './template/test_template/2.mov'
                ],
                'luts': [
                    './template/test_template/cube.cube'
                ]
            },
            {
                'source': './template/test_template/3.mp4',
                'mute': True,
            }
        ],
        'overall_template': {
            'source': None,
            'mute': False,
            'audios': [
                './template/test_template/bgm.acc'
            ]
        },
    }
    return template